@@ -1,3 +1,4 @@
+import json
 from rest_framework_proxy.views import ProxyView
 from vtixy_proxy import settings
 
@@ -6,7 +7,7 @@ class VTIXyProxyView(ProxyView):
     proxy_settings = settings.vtixy_uat_proxy_settings
 
     def get_request_data(self, request):
-        return request.DATA
+        return json.dumps(request.DATA)
 
 
 class ShowsProxy(VTIXyProxyView):
